diff --git a/web/pgadmin/static/js/sqleditor_utils.js b/web/pgadmin/static/js/sqleditor_utils.js
index 876aa52..912aa7f 100644
--- a/web/pgadmin/static/js/sqleditor_utils.js
+++ b/web/pgadmin/static/js/sqleditor_utils.js
@@ -8,8 +8,8 @@
 //////////////////////////////////////////////////////////////////////////
 // This file contains common utilities functions used in sqleditor modules
 
-define(['jquery'],
-  function ($) {
+define(['jquery', 'sources/gettext'],
+  function ($, gettext) {
     var sqlEditorUtils = {
       /* Reference link http://stackoverflow.com/questions/105034/create-guid-uuid-in-javascript
        * Modified as per requirement.
@@ -55,6 +55,63 @@ define(['jquery'],
       },
       capitalizeFirstLetter: function (string) {
         return string.charAt(0).toUpperCase() + string.slice(1);
+      },
+      updateConnectionStatus: function(url, poll_time) {
+        // This function will update the connection status
+        var $el = $(".connection_status"),
+          $blink_circle = $($el).find(".blink_circle");
+
+        setInterval(function(){
+          $.ajax({
+            url: url,
+            method: 'GET',
+            success: function (res) {
+              if(res && res.data) {
+                var status = res.data.status,
+                  msg = res.data.message;
+                // Set tooltip
+                $el.prop('title', msg);
+                // change color
+                switch(status) {
+                    // Busy
+                    case 1:
+                        $blink_circle.removeClass("connection_idle")
+                                     .removeClass("connection_failed")
+                                     .addClass('connection_busy');
+                        break;
+                    // Failed
+                    case 3:
+                    case 4:
+                        $blink_circle.removeClass("connection_idle")
+                                     .removeClass("connection_busy")
+                                     .addClass('connection_failed');
+                        break;
+                    default:
+                        $blink_circle.removeClass("connection_failed")
+                                     .removeClass("connection_busy")
+                                     .addClass('connection_idle');
+                }
+              }
+            },
+            error: function (e) {
+              var msg = gettext("Transaction status check failed.");
+              if (e.readyState == 0) {
+                msg = gettext("Not connected to the server or the connection to " +
+                              "the server has been closed.");
+              }
+              if (e.responseJSON && e.responseJSON.errormsg) {
+                msg = e.responseJSON.errormsg;
+              }
+
+              // Set tooltip
+              $el.prop('title', msg);
+              // Error
+              $blink_circle.removeClass("connection_idle")
+                           .removeClass("connection_busy")
+                           .addClass('connection_failed');
+            }
+          });
+        }, poll_time * 1000);
       }
     };
     return sqlEditorUtils;
diff --git a/web/pgadmin/tools/datagrid/templates/datagrid/index.html b/web/pgadmin/tools/datagrid/templates/datagrid/index.html
index ff4368d..f2ba5ba 100644
--- a/web/pgadmin/tools/datagrid/templates/datagrid/index.html
+++ b/web/pgadmin/tools/datagrid/templates/datagrid/index.html
@@ -1,8 +1,5 @@
 {% extends "base.html" %}
 {% block title %}{{ config.APP_NAME }} - Datagrid{% endblock %}
-{% block css_link %}
-<link type="text/css" rel="stylesheet" href="{{ url_for('sqleditor.static', filename='css/sqleditor.css') }}">
-{% endblock %}
 {% block body %}
 <style>
     body {padding: 0px;}
@@ -284,7 +281,15 @@
                 </button>
             </div>
         </div>
-        <div class="editor-title" style="background-color: {% if fgcolor %}{{ bgcolor or '#FFFFFF' }}{% else %}{{ bgcolor or '#2C76B4' }}{% endif %}; color: {{ fgcolor or 'white' }};"></div>
+
+        <div class="connection_status_wrapper">
+            <div class="connection_status" title="Database connection status">
+              <i class="fa fa-database" aria-hidden="true"></i>
+              <i class="fa fa-circle connection_idle blink_circle" aria-hidden="true"></i>
+            </div>
+            <div class="editor-title" style="background-color: {% if fgcolor %}{{ bgcolor or '#FFFFFF' }}{% else %}{{ bgcolor or '#2C76B4' }}{% endif %}; color: {{ fgcolor or 'white' }};"></div>
+        </div>
+
         <div id="filter" class="filter-container hidden">
             <div class="filter-title">Filter</div>
             <div class="sql-textarea">
diff --git a/web/pgadmin/tools/sqleditor/__init__.py b/web/pgadmin/tools/sqleditor/__init__.py
index d2b5f2e..eb6ccb3 100644
--- a/web/pgadmin/tools/sqleditor/__init__.py
+++ b/web/pgadmin/tools/sqleditor/__init__.py
@@ -50,6 +50,14 @@ TX_STATUS__ACTIVE = 1
 TX_STATUS_INTRANS = 2
 TX_STATUS_INERROR = 3
 
+# Connection status codes mapping
+CONNECTION_STATUS_MESSAGE_MAPPING = dict({
+    0: 'The session is idle and there is no current transaction.',
+    1: 'A command is currently in progress.',
+    2: 'The session is idle in a valid transaction block.',
+    3: 'The session is idle in a failed transaction block.',
+    4: 'The connection with the server is bad.'
+})
 
 class SqlEditorModule(PgAdminModule):
     """
@@ -107,7 +115,8 @@ class SqlEditorModule(PgAdminModule):
             'sqleditor.autocomplete',
             'sqleditor.load_file',
             'sqleditor.save_file',
-            'sqleditor.query_tool_download'
+            'sqleditor.query_tool_download',
+            'sqleditor.connection_status'
         ]
 
     def register_preferences(self):
@@ -333,6 +342,15 @@ class SqlEditorModule(PgAdminModule):
             }
         )
 
+        self.connection_status = self.preference.register(
+            'display', 'connection_status_fetch_time',
+            gettext("Connection status refresh rate"), 'integer', 1,
+            min_val=1, max_val=999999,
+            category_label=gettext('Display'),
+            help_str=gettext('The number of seconds between connection '
+                             'status polling.')
+        )
+
 blueprint = SqlEditorModule(MODULE_NAME, __name__, static_url_path='/static')
 
 
@@ -1807,3 +1825,50 @@ def start_query_download_tool(trans_id):
         return internal_server_error(
             errormsg=gettext("Transaction status check failed.")
         )
+
+@blueprint.route(
+    '/status/<int:trans_id>',
+    methods=["GET"],
+    endpoint='connection_status'
+)
+@login_required
+def query_tool_status(trans_id):
+    """
+    The task of this function to return the status of the current connection
+    used in query tool instance with given transaction ID.
+    Args:
+        trans_id: Transaction ID
+
+    Returns:
+        Response with the connection status
+
+        Psycopg2 Status Code Mapping:
+        -----------------------------
+        TRANSACTION_STATUS_IDLE     = 0
+        TRANSACTION_STATUS_ACTIVE   = 1
+        TRANSACTION_STATUS_INTRANS  = 2
+        TRANSACTION_STATUS_INERROR  = 3
+        TRANSACTION_STATUS_UNKNOWN  = 4
+    """
+    status, error_msg, conn, trans_obj, \
+        session_obj = check_transaction_status(trans_id)
+
+    if not status and error_msg and type(error_msg) == str:
+        return internal_server_error(
+            errormsg=error_msg
+        )
+
+    if conn and trans_obj and session_obj:
+        status = conn.conn.get_transaction_status()
+        return make_json_response(
+            data={
+                'status': status,
+                'message': gettext(
+                    CONNECTION_STATUS_MESSAGE_MAPPING.get(status)
+                )
+            }
+        )
+    else:
+        return internal_server_error(
+            errormsg=gettext("Transaction status check failed.")
+        )
diff --git a/web/pgadmin/tools/sqleditor/static/css/sqleditor.css b/web/pgadmin/tools/sqleditor/static/css/sqleditor.css
index 782d3e7..0d8eec3 100644
--- a/web/pgadmin/tools/sqleditor/static/css/sqleditor.css
+++ b/web/pgadmin/tools/sqleditor/static/css/sqleditor.css
@@ -14,7 +14,7 @@
 .sql-editor-busy-fetching {
   position:absolute;
   left: 0;
-  top: 41px;
+  top: 65px;
   bottom: 0;
   right: 0;
   margin:0;
@@ -33,11 +33,6 @@
   z-index: 0;
 }
 
-.editor-title {
-  padding: 4px 5px;
-  font-size: 13px;
-}
-
 .sql-editor-grid-container {
   height: 100%;
   overflow: auto;
@@ -524,3 +519,76 @@ input.editor-checkbox:focus {
 #datagrid .slick-row .slick-cell {
   white-space: pre;
 }
+
+#output-panel .CodeMirror {
+  border-top: 1px solid #ddd;
+}
+
+.connection_status_wrapper {
+  width: 100%;
+  background-color: #f7f7f7;
+}
+
+.editor-title {
+  width: calc(100% - 43px);
+  padding: 4px 5px;
+  font-size: 13px;
+  display: inline-block;
+}
+
+.connection_status {
+  width: 11px;
+  position: relative;
+  display: inline-block;
+  margin-top: 2px;
+  margin-left: 12px;
+  margin-right: 16px;
+}
+
+.connection_status .fa-database {
+  font-size: 16px;
+}
+
+/*
+Connection status color codes
+idle    - Green
+busy    - Orange
+failed  - Red (From Style guide)
+*/
+.connection_idle {
+  color: #32CD32;
+}
+
+.connection_busy {
+  color: #e8a735;
+}
+
+.connection_failed {
+  color: #d0021b;
+}
+
+/*
+Database icon color - Color code taken from Tree view icon
+*/
+.connection_status .fa-database {
+  color: #ac9230;
+  opacity: 0.5;
+  margin-left: 3px;
+}
+
+.connection_status .fa-circle {
+  font-size: 10px;
+  position: absolute;
+  bottom: 0;
+  right: 0;
+  margin: 1px -10px;
+}
+
+.blink_circle {
+  animation: blinker .5s cubic-bezier(.5, 0, 1, 1) infinite alternate;
+}
+
+@keyframes blinker {
+  from { opacity: 1; }
+  to { opacity: 0.1; }
+}
diff --git a/web/pgadmin/tools/sqleditor/static/js/sqleditor.js b/web/pgadmin/tools/sqleditor/static/js/sqleditor.js
index dbc416e..84cd346 100644
--- a/web/pgadmin/tools/sqleditor/static/js/sqleditor.js
+++ b/web/pgadmin/tools/sqleditor/static/js/sqleditor.js
@@ -107,6 +107,8 @@ define('tools.querytool', [
         filter = self.$el.find('#sql_filter');
 
       $('.editor-title').text(_.unescape(self.editor_title));
+      self.checkConnectionStatus();
+
       self.filter_obj = CodeMirror.fromTextArea(filter.get(0), {
         lineNumbers: true,
         mode: self.handler.server_type === "gpdb" ? "text/x-gpsql" : "text/x-pgsql",
@@ -405,6 +407,24 @@ define('tools.querytool', [
       });
     },
 
+    // This function will check the connection status at specific
+    // interval defined by the user in preference
+    checkConnectionStatus: function() {
+      var self = this,
+        preference = window.top.pgAdmin.Browser.get_preference(
+          'sqleditor', 'connection_status_fetch_time'
+        );
+      if(!preference && self.handler.is_new_browser_tab) {
+        preference = window.opener.pgAdmin.Browser.get_preference(
+                'sqleditor', 'connection_status_fetch_time'
+              )
+      }
+      SqlEditorUtils.updateConnectionStatus(
+        url_for('sqleditor.connection_status', {'trans_id': self.transId}),
+        preference.value
+      );
+    },
+
     /* To prompt user for unsaved changes */
     user_confirmation: function (panel, msg) {
       // If there is anything to save then prompt user
